@@ -1,6 +1,4 @@
 
-from datetime import datetime
-import warnings
 from io import StringIO
 
 import requests
@@ -53,31 +51,75 @@ def _get_url_and_payload(code, start_date, end_date, last):
     }
 
 
-def format_df(df, code):
-    cns = {'data': 'date', 'valor': code.name, 'datafim': 'end_date'}
+def _format_df(df, code, freq):
+    cns = {'data': 'Date', 'valor': code.name, 'datafim': 'enddate'}
     df = df.rename(columns=cns)
-    if 'date' in df:
-        df['date'] = pd.to_datetime(df['date'], format='%d/%m/%Y')
-    if 'end_date' in df:
-        df['end_date'] = pd.to_datetime(df['end_date'], format='%d/%m/%Y')
-    df = df.set_index('date')
+    if 'Date' in df:
+        df['Date'] = pd.to_datetime(df['Date'], format='%d/%m/%Y')
+    if 'enddate' in df:
+        df['enddate'] = pd.to_datetime(df['enddate'], format='%d/%m/%Y')
+    df = df.set_index('Date')
+    if freq:
+        df.index = df.index.to_period(freq)
     return df
 
 
-def get(codes, start_date=None, end_date=None, last=0, join=False):
+def get(codes, start=None, end=None, last=0, multi=True, freq=None):
+    '''
+    Retorna um DataFrame pandas com séries temporais obtidas do SGS.
+
+    Parameters
+    ----------
+
+    ``symbols`` : {int, List[int], List[str], Dict[str:int]}
+        Este argumento pode ser uma das opções:
+
+        ``int`` : código da série temporal
+
+        ``list`` ou ``tuple`` : lista ou tupla com pares ``('nome', código)``
+
+        ``dict`` : dicionário com pares ``{'nome': código}``
+
+        Com códigos numéricos é interessante utilizar os nomes com os códigos
+        para definir os nomes nas colunas das séries temporais.
+    ``start`` : str, int, date, datetime, Timestamp
+        Data de início da série.
+        Interpreta diferentes tipos e formatos de datas.
+    ``end`` : string, int, date, datetime, Timestamp
+        Data de início da série.
+        Interpreta diferentes tipos e formatos de datas.
+    ``last`` : int
+        Retorna os últimos ``last`` elementos disponíveis da série temporal
+        solicitada. Se ``last`` for maior que 0 (zero) os argumentos ``start``
+        e ``end`` são ignorados.
+    ``multi`` : bool
+        Define se, quando mais de 1 série for solicitada, a função retorna uma
+        série multivariada ou uma lista com séries univariadas.
+
+    Returns
+    -------
+
+    ``DataFrame`` :
+        série temporal univariada ou multivariada,
+        quando solicitado mais de uma série.
+
+    ``list`` :
+        lista com séries temporais univariadas,
+        quando solicitado mais de uma série.
+    '''
     dfs = []
     for code in _codes(codes):
-        urd = _get_url_and_payload(code.value, start_date, end_date, last)
+        urd = _get_url_and_payload(code.value, start, end, last)
         res = requests.get(urd['url'], params=urd['payload'])
         if res.status_code != 200:
             raise Exception('Download error: code = {}'.format(code.value))
         df = pd.read_json(StringIO(res.text))
-        df = format_df(df, code)
+        df = _format_df(df, code, freq)
         dfs.append(df)
     if len(dfs) == 1:
         return dfs[0]
     else:
-        if join:
+        if multi:
             return pd.concat(dfs, axis=1)
         else:
             return dfs
